==> beast-privilege-api-2.6.6-20230316.071008-7-sources.jar: com/thebeastshop/privilege/vo/KeyMemberMemorialCustomVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class KeyMemberMemorialCustomVO implements Serializable {
    private Integer memorialId;
    private String cellPhone;
    private Date createTime;
    private Integer creatorId;
    private String creatorName;

    private List<KeyMemberMemorialCustomPersonVO> customPersonVOList;

    private List<Integer> customSystemIdList;

    public Integer getMemorialId() {
        return memorialId;
    }

    public void setMemorialId(Integer memorialId) {
        this.memorialId = memorialId;
    }

    public String getCellPhone() {
        return cellPhone;
    }

    public void setCellPhone(String cellPhone) {
        this.cellPhone = cellPhone;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public List<KeyMemberMemorialCustomPersonVO> getCustomPersonVOList() {
        return customPersonVOList;
    }

    public void setCustomPersonVOList(List<KeyMemberMemorialCustomPersonVO> customPersonVOList) {
        this.customPersonVOList = customPersonVOList;
    }

    public List<Integer> getCustomSystemIdList() {
        return customSystemIdList;
    }

    public void setCustomSystemIdList(List<Integer> customSystemIdList) {
        this.customSystemIdList = customSystemIdList;
    }


}

==> beast-privilege-api-2.6.6-20230316.084232-8-sources.jar: com/thebeastshop/privilege/vo/KeyMemberMemorialCustomVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class KeyMemberMemorialCustomVO implements Serializable {
    private Integer memorialId;
    private String cellPhone;
    private Date createTime;
    private Integer creatorId;
    private String creatorName;

    private List<KeyMemberMemorialCustomPersonVO> customPersonVOList;
    private List<Integer> customSystemIdList;



    private List<Integer> innerDelCustomPersonIds;
    private List<Integer> innerAddCustomSystemIds;
    private List<Integer> innerDelCustomSystemIds;


    public Integer getMemorialId() {
        return memorialId;
    }

    public void setMemorialId(Integer memorialId) {
        this.memorialId = memorialId;
    }

    public String getCellPhone() {
        return cellPhone;
    }

    public void setCellPhone(String cellPhone) {
        this.cellPhone = cellPhone;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public List<KeyMemberMemorialCustomPersonVO> getCustomPersonVOList() {
        return customPersonVOList;
    }

    public void setCustomPersonVOList(List<KeyMemberMemorialCustomPersonVO> customPersonVOList) {
        this.customPersonVOList = customPersonVOList;
    }

    public List<Integer> getCustomSystemIdList() {
        return customSystemIdList;
    }

    public void setCustomSystemIdList(List<Integer> customSystemIdList) {
        this.customSystemIdList = customSystemIdList;
    }

    public List<Integer> getInnerDelCustomPersonIds() {
        return innerDelCustomPersonIds;
    }

    public void setInnerDelCustomPersonIds(List<Integer> innerDelCustomPersonIds) {
        this.innerDelCustomPersonIds = innerDelCustomPersonIds;
    }

    public List<Integer> getInnerAddCustomSystemIds() {
        return innerAddCustomSystemIds;
    }

    public void setInnerAddCustomSystemIds(List<Integer> innerAddCustomSystemIds) {
        this.innerAddCustomSystemIds = innerAddCustomSystemIds;
    }

    public List<Integer> getInnerDelCustomSystemIds() {
        return innerDelCustomSystemIds;
    }

    public void setInnerDelCustomSystemIds(List<Integer> innerDelCustomSystemIds) {
        this.innerDelCustomSystemIds = innerDelCustomSystemIds;
    }

}
